summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2011-01-26 22:04:03 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2011-01-26 22:05:32 -0600
commit0012e9cd5462ce9f960855db066422279356887d (patch)
treeeb35a7a9c9ab6c3d7e5eb83fe459043de8a75096
parent8d0bc0f0261a0ee1fdbc57d28036662c11ab3053 (diff)
downloadlibpng-0012e9cd5462ce9f960855db066422279356887d.tar.gz
[devel] Imported from libpng-1.5.1beta10.tarv1.5.1beta10
-rw-r--r--ANNOUNCE9
-rw-r--r--CHANGES7
-rw-r--r--LICENSE4
-rw-r--r--Makefile.am3
-rw-r--r--Makefile.in4
-rw-r--r--README2
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.314
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
15 files changed, 41 insertions, 32 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 900da48ce..141176679 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.5.1beta10 - January 26, 2011
+Libpng 1.5.1beta10 - January 27, 2011
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -96,16 +96,17 @@ Version 1.5.1beta09 [January 24, 2011]
documentation did not accurately describe what libpng really does when
converting RGB to gray.
-Version 1.5.1beta10 [January 26, 2011]
+Version 1.5.1beta10 [January 27, 2011]
Fixed incorrect examples of callback prototypes in the manual, that were
introduced in libpng-1.0.0.
In addition the order of the png_get_uint macros with respect to the
relevant function definitions has been reversed. This helps the
preprocessing of the symbol files be more robust. Furthermore, the
- symbol file preprocessing now uses -DPNG_NO_USE_READ_MACROS; this stops
+ symbol file preprocessing now uses -DPNG_NO_USE_READ_MACROS even when
+ the library may actually be built with PNG_USE_READ_MACROS; this stops
the read macros interfering with the symbol file format.
Made the manual, synopses, and function prototypes use the function
- argument names file_gamma, int_file_gamma, and srgb_intent consistent.
+ argument names file_gamma, int_file_gamma, and srgb_intent consistently.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net:
(subscription required; visit
diff --git a/CHANGES b/CHANGES
index 428fbd740..6b18c8f60 100644
--- a/CHANGES
+++ b/CHANGES
@@ -3212,16 +3212,17 @@ Version 1.5.1beta09 [January 24, 2011]
documentation did not accurately describe what libpng really does when
converting RGB to gray.
-Version 1.5.1beta10 [January 26, 2011]
+Version 1.5.1beta10 [January 27, 2011]
Fixed incorrect examples of callback prototypes in the manual, that were
introduced in libpng-1.0.0.
In addition the order of the png_get_uint macros with respect to the
relevant function definitions has been reversed. This helps the
preprocessing of the symbol files be more robust. Furthermore, the
- symbol file preprocessing now uses -DPNG_NO_USE_READ_MACROS; this stops
+ symbol file preprocessing now uses -DPNG_NO_USE_READ_MACROS even when
+ the library may actually be built with PNG_USE_READ_MACROS; this stops
the read macros interfering with the symbol file format.
Made the manual, synopses, and function prototypes use the function
- argument names file_gamma, int_file_gamma, and srgb_intent consistent.
+ argument names file_gamma, int_file_gamma, and srgb_intent consistently.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/LICENSE b/LICENSE
index f105226af..17b87e499 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.1beta10, January 24, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.1beta10, January 27, 2011, are
Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-January 24, 2011
+January 27, 2011
diff --git a/Makefile.am b/Makefile.am
index bff416557..142a4ceae 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -118,6 +118,9 @@ scripts/pnglibconf.h.prebuilt:
# 'make test' is the first thing the user does.)
pngvalid.o pngtest.o: pnglibconf.h
+# We must use -DPNG_NO_USE_READ_MACROS here even when the library may actually
+# be built with PNG_USE_READ_MACROS; this stops the read macros interfering
+# with the symbol file format.
SYMBOL_CFLAGS = -DPNGLIB_LIBNAME='PNG@PNGLIB_MAJOR@@PNGLIB_MINOR@_0'\
-DPNGLIB_VERSION='@PNGLIB_VERSION@'\
-DSYMBOL_PREFIX='$(SYMBOL_PREFIX)'\
diff --git a/Makefile.in b/Makefile.in
index 9576c2a99..d2febdd2b 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -355,6 +355,10 @@ MAINTAINERCLEANFILES = Makefile.in aclocal.m4 config.guess config.h.in \
config.sub configure depcomp install-sh ltmain.sh missing
SUFFIXES = .chk .dfn .out
+
+# We must use -DPNG_NO_USE_READ_MACROS here even when the library may actually
+# be built with PNG_USE_READ_MACROS; this stops the read macros interfering
+# with the symbol file format.
SYMBOL_CFLAGS = -DPNGLIB_LIBNAME='PNG@PNGLIB_MAJOR@@PNGLIB_MINOR@_0'\
-DPNGLIB_VERSION='@PNGLIB_VERSION@'\
-DSYMBOL_PREFIX='$(SYMBOL_PREFIX)'\
diff --git a/README b/README
index b7686056b..e4ef527f2 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.1beta10 - January 24, 2011 (shared library 15.0)
+README for libpng version 1.5.1beta10 - January 27, 2011 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 1dfe471e6..10eb6f6ed 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.1beta10 - January 26, 2011
+ libpng version 1.5.1beta10 - January 27, 2011
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.1beta10 - January 26, 2011
+ libpng versions 0.97, January 1998, through 1.5.1beta10 - January 27, 2011
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -4080,7 +4080,7 @@ Other rules can be inferred by inspecting the libpng source.
XIV. Y2K Compliance in libpng
-January 26, 2011
+January 27, 2011
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
diff --git a/libpng.3 b/libpng.3
index 00cef8af1..6258a3476 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "January 26, 2011"
+.TH LIBPNG 3 "January 27, 2011"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.1beta10
.SH SYNOPSIS
@@ -919,7 +919,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.1beta10 - January 26, 2011
+ libpng version 1.5.1beta10 - January 27, 2011
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -930,7 +930,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.1beta10 - January 26, 2011
+ libpng versions 0.97, January 1998, through 1.5.1beta10 - January 27, 2011
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -4999,7 +4999,7 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIV. Y2K Compliance in libpng
-January 26, 2011
+January 27, 2011
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
@@ -5245,7 +5245,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.1beta10 - January 26, 2011:
+Libpng version 1.5.1beta10 - January 27, 2011:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -5268,7 +5268,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.1beta10, January 26, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.1beta10, January 27, 2011, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -5367,7 +5367,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-January 26, 2011
+January 27, 2011
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 2f80e1352..b1682e780 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "January 24, 2011"
+.TH LIBPNGPF 3 "January 27, 2011"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.1beta10
(private functions)
diff --git a/png.5 b/png.5
index ce7988b82..26e41f8d3 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "January 24, 2011"
+.TH PNG 5 "January 27, 2011"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 881f06ac6..f21e054c3 100644
--- a/png.c
+++ b/png.c
@@ -555,13 +555,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.1beta10 - January 24, 2011" PNG_STRING_NEWLINE \
+ "libpng version 1.5.1beta10 - January 27, 2011" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2011 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.1beta10 - January 24, 2011\
+ return "libpng version 1.5.1beta10 - January 27, 2011\
Copyright (c) 1998-2011 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 2e43cf884..10c3d7186 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.1beta10 - January 24, 2011
+libpng version 1.5.1beta10 - January 27, 2011
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 1fce3ebff..530602e08 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.1beta10 - January 24, 2011
+ * libpng version 1.5.1beta10 - January 27, 2011
*
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 277ce4d16..ca1d46f10 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.5.1beta10 - January 24, 2011
+Makefiles for libpng version 1.5.1beta10 - January 27, 2011
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/png.h b/png.h
index 4579af3ea..b9bcb48b8 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.1beta10 - January 26, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.1beta10 - January 26, 2011: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -176,7 +176,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.1beta10, January 26, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -288,7 +288,7 @@
* Y2K compliance in libpng:
* =========================
*
- * January 26, 2011
+ * January 27, 2011
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -352,7 +352,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.5.1beta10"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.1beta10 - January 26, 2011\n"
+ " libpng version 1.5.1beta10 - January 27, 2011\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.1beta10 - January 26, 2011
+ * libpng version 1.5.1beta10 - January 27, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.1beta10 - January 26, 2011: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.1beta10 - January 27, 2011: Glenn
* See also "Contributing Authors", below.
*
@@ -176,7 +176,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.1beta10, January 26, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.1beta10, January 27, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5